/*	$calcurse: help.h,v 1.9 2008/12/20 19:27:31 culot Exp $	*/

/*
 * Calcurse - text-based organizer
 * Copyright (c) 2004-2008 Frederic Culot
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Send your feedback or comments to : calcurse@culot.org
 * Calcurse home page : http://culot.org/calcurse
 *
 */

#ifndef CALCURSE_HELP_H
#define CALCURSE_HELP_H

#include "wins.h"

#define HELPTEXTSIZ 4096

typedef struct {
  char *title;
  char text[HELPTEXTSIZ];
} help_page_t;

void help_wins_init (scrollwin_t *, int, int, int, int);
void help_screen (void);

#endif /* CALCURSE_HELP_H */
